@@ -186,6 +186,10 @@ class Dialog(gtk.Window):
         self.priority = Priority()
         add_control(self.priority, "Priority:")
 
+        row += 1
+        self.wait_date = gtk.Entry()
+        add_control(self.wait_date, "Wait until:")
+
         row += 1
         self.tags = Tags()
         add_control(self.tags, "Tags:")
@@ -348,6 +352,10 @@ class Dialog(gtk.Window):
         if tmp is not None and tmp != self.task.get("priority"):
             update["priority"] = tmp
 
+        tmp = self.wait_date.get_text()
+        if tmp and tmp != self.task.get("wait"):
+            pass
+
         tmp = "completed" if self.completed.get_active() else "pending"
         if tmp is not None and tmp != self.task.get("status"):
             update["status"] = tmp
